@@ -451,40 +451,48 @@ def rescore_member(
     session = boto3.Session()
     s3 = session.resource("s3")
 
-    preservations = get_annotation(
-        s3client=s3client,
-        annotations_bucket=ANNOTATION_BUCKET,
-        annotations_path=ANNOTATION_PATH,
-        member_id=member_id,
-        annotation_name="preservation.json",
-    )
+    import environment
 
-    one_archive = preservations["preserved-in-one-archive"]
-    two_archives = preservations["preserved-in-two-archives"]
-    three_archives = preservations["preserved-in-three-or-more-archives"]
+    environment.setup_environment(code_bucket, download_settings=False)
 
-    sample_count = preservations["sample-count"]
+    try:
+        preservations = get_annotation(
+            s3client=s3client,
+            annotations_bucket=ANNOTATION_BUCKET,
+            annotations_path=ANNOTATION_PATH,
+            member_id=member_id,
+            annotation_name="preservation.json",
+        )
 
-    # determine the classes
-    preservations["member-grade"] = score(
-        one_archive,
-        two_archives,
-        three_archives,
-        preservations["sample-count"],
-    )
+        one_archive = preservations["preserved-in-one-archive"]
+        two_archives = preservations["preserved-in-two-archives"]
+        three_archives = preservations["preserved-in-three-or-more-archives"]
 
-    key = f"{annotation_path}/members/{member_id}/{annotation_filename}"
+        sample_count = preservations["sample-count"]
 
-    logging.info(
-        f"Rescoring member {member_id} as {preservations['member-grade']}"
-    )
+        # determine the classes
+        preservations["member-grade"] = score(
+            one_archive,
+            two_archives,
+            three_archives,
+            preservations["sample-count"],
+        )
 
-    push_json_to_s3(
-        s3=s3,
-        json_obj=preservations,
-        bucket=annotation_bucket,
-        path=key,
-    )
+        key = f"{annotation_path}/members/{member_id}/{annotation_filename}"
+
+        logging.info(
+            f"Rescoring member {member_id} as {preservations['member-grade']}"
+        )
+
+        push_json_to_s3(
+            s3=s3,
+            json_obj=preservations,
+            bucket=annotation_bucket,
+            path=key,
+        )
+    except Exception as e:
+        logging.error(f"Unable to rescore member {member_id}. Error follows.")
+        raise e
 
 
 def overall_report(members=None, limit=0):
